==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/docking/translations/docking_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Barra</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Parti minimizzato</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Visualizza notifiche sulla barra</translation>
    </message>
    <message>
        <source>New message tray icon</source>
        <translation>Icona del nuovo messaggio sulla barra</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Stato corrente
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Descrizione:
%2</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Esci da Kadu</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/docking/translations/docking_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Barra</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Parti minimizzato</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Visualizza notifiche sulla barra</translation>
    </message>
    <message>
        <source>New chat tray icon</source>
        <translation>Icona del nuovo chat sulla barra</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Stato corrente
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Descrizione:
%2</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Esci da Kadu</translation>
    </message>
</context>
</TS>
